Level

Struct Level 

pub struct Level { /* private fields */ }
Main container for game objects.

Each Level has a name and a vector of owned objects.

Implementations

Source

impl Level

pub fn new(name: String, content: Vec<Box<dyn Object>>) -> Self

Constructs Level with given name and content.

pub fn get_name(&self) -> &str

Get level’s name.

pub fn draw(&self)

Prints on screen it’s own name and then all stored objects.

pub fn handle( &mut self, sender: &mut dyn Entity, target: i32, action: Action, ) -> Result<(), GameError>

Handles players’ actions.

sender is the Entity that issued an action.

target is the index of targeted object in content

pub fn add_child(&mut self, item: Box<impl Item + 'static>)

pub fn get_objects(&mut self) -> &mut Vec<Box<dyn Object>>